@@ -44,6 +44,8 @@
 # 2016-06-03: added SSP and SSPE args to print.summary.Anova.mlm(). John
 # 2016-06-25: added code to optionally print univariate ANOVAs for a mlm. John
 # 2017-03-08: fixed bug in print.summary.Anova.mlm(). John
+# 2017-11-09: made compatible with vcov() in R 3.5.0. John
+# 2017-11-13,14: further fixes for vcov() John
 #-------------------------------------------------------------------------------
 
 # Type II and III tests for linear, generalized linear, and other models (J. Fox)
@@ -132,7 +134,7 @@ Anova.II.lm <- function(mod, error, singular.ok=TRUE, ...){
 		hyp.matrix.2 <- I.p[c(subs.relatives,subs.term),,drop=FALSE]
 		hyp.matrix.2 <- hyp.matrix.2[, not.aliased, drop=FALSE]
 		hyp.matrix.term <- if (nrow(hyp.matrix.1) == 0) hyp.matrix.2
-				else t(ConjComp(t(hyp.matrix.1), t(hyp.matrix.2), vcov(mod)))
+				else t(ConjComp(t(hyp.matrix.1), t(hyp.matrix.2), vcov(mod, complete=FALSE)))
 		hyp.matrix.term <- hyp.matrix.term[!apply(hyp.matrix.term, 1, 
 						function(x) all(x == 0)), , drop=FALSE]
 		if (nrow(hyp.matrix.term) == 0)
@@ -231,7 +233,7 @@ Anova.III.lm <- function(mod, error, singular.ok=FALSE, ...){
 # generalized linear models
 
 Anova.glm <- function(mod, type=c("II","III", 2, 3), test.statistic=c("LR", "Wald", "F"), 
-		error, error.estimate=c("pearson", "dispersion", "deviance"), singular.ok, ...){
+		error, error.estimate=c("pearson", "dispersion", "deviance"), vcov.=NULL, singular.ok, ...){
 	type <- as.character(type)
 	type <- match.arg(type)
 	if (has.intercept(mod) && length(coef(mod)) == 1 
@@ -244,6 +246,8 @@ Anova.glm <- function(mod, type=c("II","III", 2, 3), test.statistic=c("LR", "Wal
 	}
 	test.statistic <- match.arg(test.statistic)
 	error.estimate <- match.arg(error.estimate)
+	if (!is.null(vcov.)) return(Anova.default(mod, type=type, vcov.=vcov., 
+	                                               singular.ok=singular.ok, ...))
 	switch(type,
 			II=switch(test.statistic,
 					LR=Anova.II.LR.glm(mod, singular.ok=singular.ok),
@@ -1209,16 +1213,16 @@ Anova.coxph <- function(mod, type=c("II","III", 2, 3), test.statistic=c("LR", "W
 	switch(type,
 			II=switch(test.statistic,
 					LR=Anova.II.LR.coxph(mod),
-					Wald=Anova.default(mod, type="II", test.statistic="Chisq", vcov.=vcov(mod))),
+					Wald=Anova.default(mod, type="II", test.statistic="Chisq", vcov.=vcov(mod, complete=FALSE))),
 			III=switch(test.statistic,
 					LR=Anova.III.LR.coxph(mod),
-					Wald=Anova.default(mod, type="III", test.statistic="Chisq", vcov.=vcov(mod))),
+					Wald=Anova.default(mod, type="III", test.statistic="Chisq", vcov.=vcov(mod, complete=FALSE))),
 			"2"=switch(test.statistic,
 					LR=Anova.II.LR.coxph(mod),
-					Wald=Anova.default(mod, type="II", test.statistic="Chisq", vcov.=vcov(mod))),
+					Wald=Anova.default(mod, type="II", test.statistic="Chisq", vcov.=vcov(mod, complete=FALSE))),
 			"3"=switch(test.statistic,
 					LR=Anova.III.LR.coxph(mod),
-					Wald=Anova.default(mod, type="III", test.statistic="Chisq", vcov.=vcov(mod))))
+					Wald=Anova.default(mod, type="III", test.statistic="Chisq", vcov.=vcov(mod, complete=FALSE))))
 }
 
 Anova.II.LR.coxph <- function(mod, ...){
@@ -1284,7 +1288,7 @@ Anova.III.LR.coxph <- function(mod, ...){
 # parametric survival regression models
 
 alias.survreg <- function(model){
-	if(any(which <- diag(vcov(model)) < 1e-10)) return(list(Complete=which))
+	if(any(which <- diag(vcov(model, complete=FALSE)) < 1e-10)) return(list(Complete=which))
 	else list()
 }
 
@@ -1404,14 +1408,14 @@ Anova.III.LR.survreg <- function(mod, ...){
 }
 
 Anova.II.Wald.survreg <- function(mod){
-	V <- vcov(mod)
+	V <- vcov(mod, complete=FALSE)
 	p <- which(rownames(V) == "Log(scale)")
 	if (length(p) > 0) V <- V[-p, -p]
 	Anova.II.default(mod, V, test="Chisq")
 }
 
 Anova.III.Wald.survreg <- function(mod){
-	V <- vcov(mod)
+	V <- vcov(mod, complete=FALSE)
 	p <- which(rownames(V) == "Log(scale)")
 	if (length(p) > 0) V <- V[-p, -p]
 	Anova.III.default(mod, V, test="Chisq")
@@ -1420,7 +1424,7 @@ Anova.III.Wald.survreg <- function(mod){
 # Default Anova() method: requires methods for vcov() (if vcov. argument not specified) and coef().
 
 Anova.default <- function(mod, type=c("II","III", 2, 3), test.statistic=c("Chisq", "F"), 
-		vcov.=vcov(mod), singular.ok, ...){
+		vcov.=vcov(mod, complete=FALSE), singular.ok, ...){
     if (is.function(vcov.)) vcov. <- vcov.(mod)
 	type <- as.character(type)
 	type <- match.arg(type)
@@ -1593,7 +1597,7 @@ fixef <- function (object){
 
 Anova.merMod <- function(mod, type=c("II","III", 2, 3), 
                          test.statistic=c("Chisq", "F"),
-                         vcov.=vcov(mod), singular.ok, ...){
+                         vcov.=vcov(mod, complete=FALSE), singular.ok, ...){
     if (is.function(vcov.)) vcov. <- vcov.(mod)
     type <- as.character(type)
     type <- match.arg(type)
@@ -1605,7 +1609,7 @@ Anova.merMod <- function(mod, type=c("II","III", 2, 3),
 }
 
 Anova.mer <- function(mod, type=c("II","III", 2, 3), test.statistic=c("Chisq", "F"),
-		vcov.=vcov(mod), singular.ok, ...){
+		vcov.=vcov(mod, complete=FALSE), singular.ok, ...){
     if (is.function(vcov.)) vcov. <- vcov.(mod)
 	type <- as.character(type)
 	type <- match.arg(type)
@@ -1655,7 +1659,7 @@ Anova.II.mer <- function(mod, vcov., singular.ok=TRUE, test=c("Chisq", "F"), ...
 #					if (!require("pbkrtest")) stop("pbkrtest package required for F-tests on linear mixed model")
 					as.matrix(vcovAdj(mod, details=0))
 				}
-				else vcov(mod)
+				else vcov(mod, complete=FALSE)
 	}
 	assign <- attr(model.matrix(mod), "assign")
 	assign[!not.aliased] <- NA
@@ -1707,7 +1711,7 @@ Anova.III.mer <- function(mod, vcov., singular.ok=FALSE, test=c("Chisq", "F"), .
 #					if (!require("pbkrtest")) stop("pbkrtest package required for F-tests on linear mixed model")
 					as.matrix(vcovAdj(mod, details=0))
 				}
-				else vcov(mod)
+				else vcov(mod, complete=FALSE)
 	}
 	for (term in 1:n.terms){
 		subs <- which(assign == term - intercept)        
@@ -1755,7 +1759,7 @@ Anova.III.mer <- function(mod, vcov., singular.ok=FALSE, test=c("Chisq", "F"), .
 }
 
 Anova.lme <- function(mod, type=c("II","III", 2, 3),
-		vcov.=vcov(mod), singular.ok, ...){
+		vcov.=vcov(mod, complete=FALSE), singular.ok, ...){
     if (is.function(vcov.)) vcov. <- vcov.(mod)
 	type <- as.character(type)
 	type <- match.arg(type)
