@@ -17,6 +17,8 @@
 # 2013-07-01: New 'constants' argument for use when called from within a function.
 # 2013-07-18: fixed a bug in passing the 'func' argument
 # 2016-03-31: added level argument and report CIs. J. Fox
+# 2017-11-09: make compatible with vcov() in R 3.5.0. J. Fox
+# 2017-11-13: further fixes for vcov(). J. Fox
 #-------------------------------------------------------------------------------
 
 deltaMethod <- function (object, ...) {
@@ -29,7 +31,7 @@ deltaMethod.default <- function (object, g, vcov., func = g, constants, level=0.
 	if ((exists.method("coef", object, default=FALSE) ||
 				(!is.atomic(object) && !is.null(object$coefficients))) 
 			&& exists.method("vcov", object, default=FALSE)){
-		if (missing(vcov.)) vcov. <- vcov(object)
+		if (missing(vcov.)) vcov. <- vcov(object, complete=FALSE)
 		object <- coef(object)
 	}
 	para <- object         
@@ -59,7 +61,7 @@ deltaMethod.default <- function (object, g, vcov., func = g, constants, level=0.
 	result
 }
 
-deltaMethod.lm <- function (object, g, vcov. = vcov, 
+deltaMethod.lm <- function (object, g, vcov. = vcov(object, complete=FALSE), 
            parameterNames = names(coef(object)), ...) {
 #  if( !exists("deltaMethodMessageFlag", envir=.carEnv)){
 #     message("deltaMethod arguments have changed, see help(deltaMethod)")
@@ -76,12 +78,12 @@ deltaMethod.lm <- function (object, g, vcov. = vcov,
 }
 
 # nls has named parameters so parameterNames is ignored
-deltaMethod.nls <- function(object, g, vcov.=vcov,...){
+deltaMethod.nls <- function(object, g, vcov.=vcov(object, complete=FALSE),...){
 	vcov. <- if(is.function(vcov.)) vcov.(object)
 	deltaMethod.default(coef(object), g, vcov., ...)   
 }
 
-deltaMethod.polr <- function(object,g,vcov.=vcov,...){
+deltaMethod.polr <- function(object, g, vcov.=vcov,...){
 	sel <- 1:(length(coef(object)))
 	vcov. <- if(is.function(vcov.)) vcov.(object)[sel, sel]
 	deltaMethod.lm(object, g, vcov., ...)
@@ -104,25 +106,25 @@ deltaMethod.multinom <- function(object, g, vcov.=vcov,
 	out}
 
 # method for survreg objects. 
-deltaMethod.survreg <- function(object, g, vcov. = vcov, 
+deltaMethod.survreg <- function(object, g, vcov. = vcov(object, complete=FALSE), 
            parameterNames = names(coef(object)), ...) {
  deltaMethod.lm(object, g, vcov., parameterNames , ...) }
 
 
  # method for coxph objects.
-deltaMethod.coxph <- function(object, g, vcov. = vcov, 
+deltaMethod.coxph <- function(object, g, vcov. = vcov(object, complete=FALSE), 
            parameterNames = names(coef(object)), ...) {
  deltaMethod.lm(object, g, vcov.,  parameterNames, ...) }
            
 # lmer
 
-deltaMethod.merMod <- function(object, g, vcov. = vcov,
+deltaMethod.merMod <- function(object, g, vcov. = vcov(object, complete=FALSE),
                             parameterNames = names(fixef(object)), ...) {
     deltaMethod.mer(object=object, g=g, vcov.=vcov, 
                        parameterNames=parameterNames, ...)
 }
     
-deltaMethod.mer <- function(object, g, vcov. = vcov,
+deltaMethod.mer <- function(object, g, vcov. = vcov(object, complete=FALSE),
            parameterNames = names(fixef(object)), ...) {
   para <- fixef(object)
   names(para) = parameterNames
@@ -134,7 +136,7 @@ deltaMethod.mer <- function(object, g, vcov. = vcov,
 
 
 #lme
-deltaMethod.lme <- function(object, g, vcov. = vcov,
+deltaMethod.lme <- function(object, g, vcov. = vcov(object, complete=FALSE),
            parameterNames = names(fixef(object)), ...) {
   para <- fixef(object)
   names(para) = parameterNames
