@@ -33,6 +33,8 @@
 #   2015-01-27: KRmodcomp() and methods now imported from pbkrtest. John
 #   2015-02-03: Check for NULL df before 0 df in default method. John
 #   2016-06-29: added "value" and "vcov" attributes to returned object, print vcov when verbose. John
+#   2017-11-09: make compatible with vcov() in R 3.5.0. J. Fox
+#   2017-11-13: further fixes for vcov(). J. Fox
 #----------------------------------------------------------------------------------------------------
 
 vcov.default <- function(object, ...){
@@ -188,8 +190,8 @@ linearHypothesis.default <- function(model, hypothesis.matrix, rhs=NULL,
 	df <- df.residual(model)
 	if (is.null(df)) df <- Inf ## if no residual df available
     if (df == 0) stop("residual df = 0")
-	V <- if (is.null(vcov.)) vcov(model)
-			else if (is.function(vcov.)) vcov.(model) else vcov.
+	V <- if (is.null(vcov.)) vcov(model, complete=FALSE)
+			else if (is.function(vcov.)) vcov.(model)  else vcov.
 	b <- coef.
 	if (any(aliased <- is.na(b)) && !singular.ok)
 		stop("there are aliased coefficients in the model")
@@ -515,7 +517,7 @@ print.linearHypothesis.mlm <- function(x, SSP=TRUE, SSPE=SSP,
 linearHypothesis.survreg <- function(model, hypothesis.matrix, rhs=NULL,
 		test=c("Chisq", "F"), vcov., verbose=FALSE, ...){
 	if (missing(vcov.)) {
-		vcov. <- vcov(model)
+		vcov. <- vcov(model, complete=FALSE)
 		p <- which(rownames(vcov.) == "Log(scale)")
 		if (length(p) > 0) vcov. <- vcov.[-p, -p]
 	}
@@ -524,7 +526,7 @@ linearHypothesis.survreg <- function(model, hypothesis.matrix, rhs=NULL,
 
 linearHypothesis.polr <- function (model, hypothesis.matrix, rhs=NULL, vcov., verbose=FALSE, ...){
 	k <- length(coef(model))
-	V <- vcov(model)[1:k, 1:k]
+	V <- vcov(model, complete=FALSE)[1:k, 1:k]
 	linearHypothesis.default(model, hypothesis.matrix, rhs, vcov.=V, verbose=verbose, ...)
 }
 
@@ -569,8 +571,8 @@ linearHypothesis.merMod <- function(model, hypothesis.matrix, rhs=NULL,
 linearHypothesis.mer <- function(model, hypothesis.matrix, rhs=NULL,
                                  vcov.=NULL, test=c("Chisq", "F"), singular.ok=FALSE, verbose=FALSE, ...){
     test <- match.arg(test)
-    V <- as.matrix(if (is.null(vcov.))vcov(model)
-                   else if (is.function(vcov.)) vcov.(model) else vcov.)
+    V <- as.matrix(if (is.null(vcov.))vcov(model, complete=FALSE)
+                   else if (is.function(vcov.)) vcov.(model)  else vcov.)
     b <- fixef(model)
     if (any(aliased <- is.na(b)) && !singular.ok)
         stop("there are aliased coefficients in the model")
@@ -641,8 +643,8 @@ linearHypothesis.mer <- function(model, hypothesis.matrix, rhs=NULL,
 
 linearHypothesis.lme <- function(model, hypothesis.matrix, rhs=NULL,
 		vcov.=NULL, singular.ok=FALSE, verbose=FALSE, ...){
-	V <- as.matrix(if (is.null(vcov.))vcov(model)
-					else if (is.function(vcov.)) vcov.(model) else vcov.)
+	V <- as.matrix(if (is.null(vcov.))vcov(model, complete=FALSE)
+					else if (is.function(vcov.)) vcov.(model)  else vcov.)
 	b <- fixef(model)
 	if (any(aliased <- is.na(b)) && !singular.ok)
 		stop("there are aliased coefficients in the model")
